<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

require_once 'HTTP/Request.php';

/**
 *  Trackbackクラス
 *
 *  @author     Shogo Minami
 *  @access     public
 *  @package    Pocket
 */
class Pocket_Trackback
{
    /** @var    integer _post_id            記事ID */
    var $_post_id;

    /** @var    string  _sbs_name           SBS名称 */
    var $_sbs_name;

    /** @var    string  _title              タイトル */
    var $_title;

    /** @var    string  _url                URL */
    var $_url;

    /** @var    string  _excerpt            概要 */
    var $_excerpt;

    /** @var    string  _ip                 IPアドレス */
    var $_ip;

    /**
     *  コンストラクタ
     *
     *  @access public
     */
    function Pocket_Trackback()
    {
    }

    /**
     *  トラックバック送信
     *
     *  @access public
     *  @param  string  $trackback_url      トラックバック先のURL
     *  @param  string  $sbs_name           SBS名
     *  @param  string  $title              記事タイトル
     *  @param  string  $url                記事URL
     *  @param  string  $excerpt            記事概要
     *  @param  boolean $charset            文字コード
     */
    function send($trackback_url, $sbs_name, $title, $url, $excerpt, $charset = 'UTF-8')
    {
        // HTTPリクエストオブジェクトの生成
        $req = new HTTP_Request($trackback_url);

        // メソッドの設定
        $req->setMethod(HTTP_REQUEST_METHOD_POST);

        // 概要の文字数チェック
        if (mb_strlen($excerpt) > 128)
            $excerpt = mb_substr($excerpt, 0, 128) . '..';

        // 送信データの設定
        $req->addPostData('sbs_name', $sbs_name);
        $req->addPostData('title', $title);
        $req->addPostData('url', $url);
        $req->addPostData('excerpt', $excerpt);
        $req->addPostData('charset', $charset);

        // 送信
        $result = $req->sendRequest();

        //送信エラー
        if (PEAR::isError($result))
        {
            return false;
        }

        return true;
    }

    /**
     *  トラックバック受信
     *
     *  @access public
     */
    function receive()
    {
        // 記事IDの取得
        $post_id = $_GET['id'];
        if (!$post_id)
            $post_id = $_POST['id'];

        // その他の情報の取得
        $sbs_name  = trim($_POST['sbs_name']);
        $title     = trim($_POST['title']);
        $url       = trim($_POST['url']);
        $excerpt   = trim($_POST['excerpt']);
        $charset   = $_POST['charset'];
        $ip        = $_SERVER['REMOTE_ADDR'];

        // エンコード
        if (!empty($charset))
        {
            $sbs_name  = mb_convert_encoding($sbs_name , 'UTF-8', $charset);
            $title     = mb_convert_encoding($title    , 'UTF-8', $charset);
            $excerpt   = mb_convert_encoding($excerpt  , 'UTF-8', $charset);
        }

        // 受信情報を保持
        $this->_post_id = $post_id;
        $this->_sbs_name = $sbs_name;
        $this->_title = $title;
        $this->_url = $url;
        $this->_excerpt = $excerpt;
        $this->_ip = $ip;

        // トラックバック情報を返却
        return array(
            'post_id' => $post_id,
            'sbs_name' => $sbs_name,
            'title' => $title,
            'url' => $url,
            'excerpt' => $excerpt,
            'ip' => $ip
        );
    }

    /**
     *  トラックバック受信状況
     *
     *  @access public
     *  @return boolean true,false
     */
    function isValidReceive(&$message)
    {
        $message = '';

        // トラックバック情報のチェック
        if (!intval($this->_post_id))
        {
            $message = 'I really need an ID for this to work.';
            return false;
        }
        if ($this->_title == NULL || (is_string($this->_title) && strlen($this->_title) == 0))
        {
            $message = 'I really need an Title for this to work.';
            return false;
        }
        if ($this->_url == NULL || (is_string($this->_url) && strlen($this->_url) == 0))
        {
            $message = 'I really need an URL for this to work.';
            return false;
        }
        if ($this->_excerpt == NULL || (is_string($this->_excerpt) && strlen($this->_excerpt) == 0))
        {
            $message = 'I really need an Excerpt for this to work.';
            return false;
        }
        if ($this->_sbs_name == NULL || (is_string($this->_sbs_name) && strlen($this->_sbs_name) == 0))
        {
            $message = 'I really need an SBS name for this to work.';
            return false;
        }

        // IPブロック関数の存在チェック
        if (function_exists("pocket_isBlockIP")) {
            // トラックバックスパム対策（IPブロック対象の場合はエラー）
            if (pocket_isBlockIP($this->_ip))
            {
                $message = 'TrackBack is not Permitted.';
                return false;
            }
        }

        // トラックバックスパム対策（半角英数記号のみの場合はエラー）
        if (preg_match('/^[!-~]+$/', $this->_excerpt))
        {
            $message = 'TrackBack is not Permitted.';
            return false;
        }

        // トラックバックスパム対策（参照元にURLがない場合はエラー）
        $is_exist_url = false;
        $tb_page = @file($this->_url);
        if ($tb_page != '')
        {
           while (list($tb_num, $tb_line) = each($tb_page))
           {
              if (stristr($tb_line, pocket_getSiteUrl())) $is_exist_url = true;
           }
        }
        if (!$is_exist_url)
        {
            $message = 'TrackBack is not Permitted.';
            return false;
        }

        return true;
    }

    /**
     *  トラックバック返信
     *
     *  @access public
     *  @param  string  $err_code           エラーコード
     *  @param  string  $err_message        エラーメッセージ
     */
    function response($err_code=0, $err_message='')
    {
        header('Content-Type: text/xml; charset=UTF-8');
        echo '<?xml version="1.0" encoding="utf-8"?>' . "\n";
        if ($err_code)
        {
            echo '<response>' . "\n";
            echo '<error>' . $err_code . '</error>' . "\n";
            echo '<message>' . $err_message . '</message>' . "\n";
            echo '</response>' . "\n";
        } else {
            echo '<response>' . "\n";
            echo '<error>0</error>' . "\n";
            echo '</response>' . "\n";
        }
        exit();
    }
}

?>
