CREATE TABLE psb_access_log (
    access_log_id serial NOT NULL,
    user_agent varchar(255) NOT NULL DEFAULT '',
    ip varchar(100) NOT NULL DEFAULT '',
    host varchar(255) NOT NULL DEFAULT '',
    uri varchar(255) NOT NULL DEFAULT '',
    referer varchar(255) NOT NULL DEFAULT '',
    r_datetime timestamp without time zone NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY  (access_log_id)
);

CREATE TABLE psb_blocks (
    block_id serial NOT NULL,
    ip varchar(100) NOT NULL DEFAULT '',
    note text NOT NULL DEFAULT '',
    r_datetime timestamp without time zone NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY  (block_id)
);

CREATE TABLE psb_block_log (
    block_log_id serial NOT NULL,
    ip varchar(100) NOT NULL DEFAULT '',
    r_datetime timestamp without time zone NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY  (block_log_id)
);

CREATE TABLE psb_sbs_config (
    sbs_config_id serial NOT NULL,
    name varchar(64) NOT NULL DEFAULT '',
    value text NOT NULL DEFAULT '',
    PRIMARY KEY  (sbs_config_id)
);

CREATE TABLE psb_links (
    link_id serial NOT NULL,
    link_name varchar(255) NOT NULL DEFAULT '',
    url text NOT NULL DEFAULT '',
    sort_order integer NOT NULL DEFAULT 0,
    r_datetime timestamp without time zone NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY  (link_id)
);

CREATE TABLE psb_urls (
    url_id serial NOT NULL,
    url text NOT NULL DEFAULT '',
    is_thumbnail smallint NOT NULL DEFAULT 0,
    r_datetime timestamp without time zone NOT NULL DEFAULT CURRENT_TIMESTAMP,
    m_datetime timestamp without time zone NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY  (url_id)
);

CREATE TABLE psb_tags (
    tag_id serial NOT NULL,
    bookmark_id integer NOT NULL DEFAULT 0,
    user_id integer NOT NULL DEFAULT 0,
    url_id integer NOT NULL DEFAULT 0,
    tag text NOT NULL DEFAULT '',
    r_datetime timestamp without time zone NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY  (tag_id)
);
CREATE INDEX psb_tags_idx_bookmark_id ON psb_tags USING btree (bookmark_id);
CREATE INDEX psb_tags_idx_user_id ON psb_tags USING btree (user_id);
CREATE INDEX psb_tags_idx_url_id ON psb_tags USING btree (url_id);

CREATE TABLE psb_bookmarks (
    bookmark_id serial NOT NULL,
    user_id integer NOT NULL DEFAULT 0,
    url_id integer NOT NULL DEFAULT 0,
    subject varchar(255) NOT NULL DEFAULT '',
    explanation text NOT NULL DEFAULT '',
    open_type smallint NOT NULL DEFAULT 0,
    r_datetime timestamp without time zone NOT NULL DEFAULT CURRENT_TIMESTAMP,
    m_datetime timestamp without time zone NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY  (bookmark_id)
);
CREATE INDEX psb_bookmarks_idx_user_id ON psb_bookmarks USING btree (user_id);
CREATE INDEX psb_bookmarks_idx_url_id ON psb_bookmarks USING btree (url_id);

CREATE TABLE psb_images (
    image_id serial NOT NULL,
    title varchar(255) NOT NULL DEFAULT '',
    size integer NOT NULL,
    type varchar(255) NOT NULL DEFAULT '',
    image bytea NOT NULL,
    r_datetime timestamp without time zone NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY  (image_id)
);

CREATE TABLE psb_banner (
    banner_id serial NOT NULL,
    title varchar(255) NOT NULL DEFAULT '',
    outline text NOT NULL DEFAULT '',
    url text NOT NULL DEFAULT '',
    image_id integer NOT NULL,
    r_datetime timestamp without time zone NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY  (banner_id)
);

CREATE TABLE psb_user (
    user_id serial NOT NULL,
    id varchar(255) NOT NULL DEFAULT '',
    email bytea NOT NULL DEFAULT '',
    password bytea NOT NULL DEFAULT '',
    easy_login_id bytea NOT NULL DEFAULT '',
    nickname varchar(255) NOT NULL DEFAULT '',
    default_open_type smallint NOT NULL DEFAULT 0,
    simple_indication smallint NOT NULL DEFAULT 0,
    target_blank smallint NOT NULL DEFAULT 0,
    bookmark_size smallint NOT NULL DEFAULT 0,
    allow_login smallint NOT NULL DEFAULT 0,
    r_datetime timestamp without time zone NOT NULL DEFAULT CURRENT_TIMESTAMP,
    m_datetime timestamp without time zone NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY  (user_id)
);
