<?php
/**
 * Pocket Project
 * 
 * @copyright 2007 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  バナー情報の取得
 *
 *  @access public
 *  @param  integer $banner_id          ID
 */
function db_get_banner($banner_id)
{
    $sql = 'SELECT banner_id, title, outline, url, image_id, r_datetime' .
            ' FROM psb_banner' .
            ' WHERE banner_id = ?';
    $params = array(
        intval($banner_id)
    );
    return pocket_db_getRow($sql, $params);
}

/**
 *  バナー一覧情報の取得
 *
 *  @access public
 *  @param  integer $page               ページ番号
 *  @param  integer $page_size          ページサイズ
 */
function db_get_banner4list($page = 1, $page_size = 5)
{
    $sql = 'SELECT banner_id, title, outline, url, image_id, r_datetime' .
            ' FROM psb_banner' .
            ' ORDER BY r_datetime DESC';
    return pocket_db_getAllPage($sql, $page, $page_size);
}

/**
 *  バナー情報（ランダム）の取得
 *
 *  @access public
 *  @param  integer $page               ページ番号
 *  @param  integer $page_size          ページサイズ
 */
function db_get_banner4random($page = 1, $page_size = 5)
{
    $sql = 'SELECT banner_id, title, outline, url, image_id, r_datetime' .
            ' FROM psb_banner' .
            ' ORDER BY ' . pocket_db_getRandomFunction();
    return pocket_db_getAllPage($sql, $page, $page_size);
}

/**
 *  バナー件数の取得
 *
 *  @access public
 */
function db_get_banner_count4list()
{
    $sql = 'SELECT count(banner_id)' .
            ' FROM psb_banner';
    return pocket_db_getOne($sql);
}

/**
 *  バナー情報の登録
 *
 *  @access public
 *  @param  string  $title              タイトル
 *  @param  string  $outline            概要
 *  @param  string  $url                URL
 *  @param  integer $image_id           画像ID
 */
function db_insert_banner($title, $outline, $url, $image_id)
{
    $data = array(
        'title' => $title,
        'outline' => $outline,
        'url' => $url,
        'image_id' => intval($image_id),
        'r_datetime' => pocket_db_getNow()
    );
    return pocket_db_insert('psb_banner', $data, 'psb_banner_banner_id_seq');
}

/**
 *  バナー情報の更新
 *
 *  @access public
 *  @param  integer $banner_id          ID
 *  @param  string  $title              タイトル
 *  @param  string  $outline            概要
 *  @param  string  $url                URL
 */
function db_update_banner($banner_id, $title, $outline, $url)
{
    $data = array(
        'title' => $title,
        'outline' => $outline,
        'url' => $url
    );
    $where = array(
        'banner_id' => intval($banner_id)
    );
    return pocket_db_update('psb_banner', $data, $where);
}

/**
 *  バナー情報の削除
 *
 *  @access public
 *  @param  integer $banner_id          ID
 */
function db_delete_banner($banner_id)
{
    $banner = db_get_banner($banner_id);
    if (!$banner) {return false;}
    if (!pocket_db_delete('psb_images', 'image_id', $banner['image_id'])) {return false;}
    return pocket_db_delete('psb_banner', 'banner_id', intval($banner_id));
}

?>
