<?php
/**
 * Pocket Project
 * 
 * @copyright 2007 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  新着のブックマーク一覧情報の取得
 *
 *  @access public
 *  @param  integer $page               ページ番号
 *  @param  integer $page_size          ページサイズ
 */
function db_get_bookmarks4latest_list($page = 1, $page_size = 5)
{
    //////////////////////////////////////////////
    // MySQL4.0.x 対応のためサブクエリは使用しない
    //////////////////////////////////////////////
    $sql = 'SELECT bookmark_id, user_id, url_id, subject, explanation, r_datetime, m_datetime' .
            ' FROM psb_bookmarks' .
            ' WHERE open_type >= ?' .
            ' ORDER BY r_datetime DESC, url_id DESC';

    // 認証判定
    if (pocket_isAuth())
    {
        $params[] = POCKET_SBS_OPEN_TYPE_INSIDE;
    }
    else {
        $params[] = POCKET_SBS_OPEN_TYPE_OPEN;
    }

    $list = pocket_db_getAllPage($sql, $page, $page_size, $params);
    foreach ($list as $key => $item)
    {
        $list[$key]['nickname']     = db_get_nickname4user_id($item['user_id']);
        $list[$key]['url']          = db_get_url_string($item['url_id']);
        $list[$key]['tags_list']    = db_get_tags4bookmark_id($item['bookmark_id']);
        $list[$key]['user_count']   = db_get_bookmark_user_count4url_id($item['url_id']);
    }
    return $list;
}

/**
 *  新着のブックマーク件数の取得
 *
 *  @access public
 */
function db_get_bookmarks_count4latest_list()
{
    $sql = 'SELECT count(bookmark_id)' .
            ' FROM psb_bookmarks' .
            ' WHERE open_type >= ?';

    // 認証判定
    if (pocket_isAuth())
    {
        $params[] = POCKET_SBS_OPEN_TYPE_INSIDE;
    }
    else {
        $params[] = POCKET_SBS_OPEN_TYPE_OPEN;
    }

    return pocket_db_getOne($sql, $params);
}

/**
 *  注目のブックマーク一覧情報の取得
 *
 *  @access public
 *  @param  integer $offset             登録日付からのオフセット値（日数）
 *  @param  integer $page               ページ番号
 *  @param  integer $page_size          ページサイズ
 */
function db_get_bookmarks4hot_list($offset, $page = 1, $page_size = 5)
{
    //////////////////////////////////////////////
    // MySQL4.0.x 対応のためサブクエリは使用しない
    //////////////////////////////////////////////
    $sql = 'SELECT url_id, count(user_id) AS user_count' .
            ' FROM psb_bookmarks' .
            ' WHERE open_type >= ?';

    // 認証判定
    if (pocket_isAuth())
    {
        $params[] = POCKET_SBS_OPEN_TYPE_INSIDE;
    }
    else {
        $params[] = POCKET_SBS_OPEN_TYPE_OPEN;
    }

    // DB種別の判定
    if (pocket_db_isMySQL())
    {
        $sql .= ' AND r_datetime > DATE_ADD(?, INTERVAL ? DAY)';
    }
    else {
        $sql .= " AND r_datetime > (TIMESTAMP ? + INTERVAL '? DAY')";
    }

    $params[] = pocket_db_getNow();
    $params[] = intval($offset);

    $sql .= ' GROUP BY url_id' .
            ' ORDER BY user_count DESC, url_id DESC';

    $list = pocket_db_getAllPage($sql, $page, $page_size, $params);
    foreach ($list as $key => $item)
    {
        $latest_info = db_get_bookmark4latest_info($item['url_id']);
        $list[$key]['bookmark_id']  = $latest_info['bookmark_id'];
        $list[$key]['user_id']      = $latest_info['user_id'];
        $list[$key]['nickname']     = $latest_info['nickname'];
        $list[$key]['url']          = $latest_info['url'];
        $list[$key]['subject']      = $latest_info['subject'];
        $list[$key]['explanation']  = $latest_info['explanation'];
        $list[$key]['r_datetime']   = $latest_info['r_datetime'];
        $list[$key]['tags_list']    = db_get_tags4url_id($item['url_id']);
    }
    return $list;
}

/**
 *  人気のブックマーク一覧情報の取得
 *
 *  @access public
 *  @param  integer $page               ページ番号
 *  @param  integer $page_size          ページサイズ
 */
function db_get_bookmarks4pop_list($page = 1, $page_size = 5)
{
    //////////////////////////////////////////////
    // MySQL4.0.x 対応のためサブクエリは使用しない
    //////////////////////////////////////////////
    $sql = 'SELECT url_id, count(user_id) AS user_count' .
            ' FROM psb_bookmarks' .
            ' WHERE open_type >= ?' .
            ' GROUP BY url_id' .
            ' ORDER BY user_count DESC, url_id DESC';

    // 認証判定
    if (pocket_isAuth())
    {
        $params[] = POCKET_SBS_OPEN_TYPE_INSIDE;
    }
    else {
        $params[] = POCKET_SBS_OPEN_TYPE_OPEN;
    }

    $list = pocket_db_getAllPage($sql, $page, $page_size, $params);
    foreach ($list as $key => $item)
    {
        $latest_info = db_get_bookmark4latest_info($item['url_id']);
        $list[$key]['bookmark_id']  = $latest_info['bookmark_id'];
        $list[$key]['user_id']      = $latest_info['user_id'];
        $list[$key]['nickname']     = $latest_info['nickname'];
        $list[$key]['url']          = $latest_info['url'];
        $list[$key]['subject']      = $latest_info['subject'];
        $list[$key]['explanation']  = $latest_info['explanation'];
        $list[$key]['r_datetime']   = $latest_info['r_datetime'];
        $list[$key]['tags_list']    = db_get_tags4url_id($item['url_id']);
    }
    return $list;
}

/**
 *  人気のブックマーク件数の取得
 *
 *  @access public
 */
function db_get_bookmarks_count4pop_list()
{
    $sql = 'SELECT count(distinct(url_id))' .
            ' FROM psb_bookmarks' .
            ' WHERE open_type >= ?';

    // 認証判定
    if (pocket_isAuth())
    {
        $params[] = POCKET_SBS_OPEN_TYPE_INSIDE;
    }
    else {
        $params[] = POCKET_SBS_OPEN_TYPE_OPEN;
    }

    return pocket_db_getOne($sql, $params);
}

/**
 *  キーワード検索（タグ）のブックマーク一覧情報の取得
 *
 *  @access public
 *  @param  string  $keyword            キーワード
 *  @param  integer $user_id            ユーザID
 *  @param  integer $is_open_only       公開のみ表示フラグ
 *  @param  integer $page               ページ番号
 *  @param  integer $page_size          ページサイズ
 */
function db_get_bookmarks4tag_keyword($keyword, $user_id = null, $is_open_only = true, $page = 1, $page_size = 5)
{
    //////////////////////////////////////////////
    // MySQL4.0.x 対応のためサブクエリは使用しない
    //////////////////////////////////////////////
    $word_list = array();

    if ($keyword)
    {
        $keyword = str_replace('　', ' ', $keyword);
        $word_list = explode(' ', $keyword);
    }

    // 認証判定
    if (pocket_isAuth())
    {
        $open_type = POCKET_SBS_OPEN_TYPE_INSIDE;
    }
    else {
        $open_type = POCKET_SBS_OPEN_TYPE_OPEN;
    }

    // DB種別の判定
    if (pocket_db_isMySQL())
    {
        $sql = 'SELECT DISTINCT b.url_id AS url_id' .
                ' FROM psb_bookmarks AS b';

        foreach ($word_list as $key => $word)
        {
            $sql .= ', psb_tags AS t' . $key;
        }

        $sql .= ' WHERE 1 = 1';

        if ($user_id)
        {
            $sql .= ' AND b.user_id = ?';
            $params[] = intval($user_id);
        }

        if ($is_open_only)
        {
            $sql .= ' AND b.open_type >= ?';
            $params[] = $open_type;
        }

        foreach ($word_list as $key => $word)
        {
            $sql .= ' AND b.bookmark_id = t' . $key . '.bookmark_id';
        }

        foreach ($word_list as $key => $word)
        {
            $sql .= ' AND UPPER(t' . $key . '.tag) = UPPER(?)';
            $word = poket_db_replaceLikeWord($word);
            $params[] = $word;
        }

        $sql .= ' ORDER BY b.r_datetime DESC';
    }
    else
    {
        $sql = 'SELECT url_id FROM psb_urls WHERE url_id IN (';

        $sql .= ' SELECT DISTINCT b.url_id AS url_id' .
                ' FROM psb_bookmarks AS b';

        foreach ($word_list as $key => $word)
        {
            $sql .= ', psb_tags AS t' . $key;
        }

        $sql .= ' WHERE 1 = 1';

        if ($user_id)
        {
            $sql .= ' AND b.user_id = ?';
            $params[] = intval($user_id);
        }

        if ($is_open_only)
        {
            $sql .= ' AND b.open_type >= ?';
            $params[] = $open_type;
        }

        foreach ($word_list as $key => $word)
        {
            $sql .= ' AND b.bookmark_id = t' . $key . '.bookmark_id';
        }

        foreach ($word_list as $key => $word)
        {
            $sql .= ' AND UPPER(t' . $key . '.tag) = UPPER(?)';
            $word = poket_db_replaceLikeWord($word);
            $params[] = $word;
        }

        $sql .= ' ) ORDER BY m_datetime DESC';
    }

    $list = pocket_db_getAllPage($sql, $page, $page_size, $params);
    foreach ($list as $key => $item)
    {
        if ($user_id)
        {
            $bookmark_info = db_get_bookmark4user_url_id($user_id, $item['url_id']);
            $list[$key]['tags_list'] = db_get_tags4bookmark_id($bookmark_info['bookmark_id']);
        }
        else {
            $bookmark_info = db_get_bookmark4latest_info($item['url_id']);
            $list[$key]['tags_list'] = db_get_tags4url_id($item['url_id']);
        }
        $list[$key]['bookmark_id']  = $bookmark_info['bookmark_id'];
        $list[$key]['user_id']      = $bookmark_info['user_id'];
        $list[$key]['nickname']     = $bookmark_info['nickname'];
        $list[$key]['url']          = $bookmark_info['url'];
        $list[$key]['subject']      = $bookmark_info['subject'];
        $list[$key]['explanation']  = $bookmark_info['explanation'];
        $list[$key]['open_type']    = $bookmark_info['open_type'];
        $list[$key]['r_datetime']   = $bookmark_info['r_datetime'];
        $list[$key]['user_count']   = db_get_bookmark_user_count4url_id($item['url_id']);
    }
    return $list;
}

/**
 *  キーワード検索（タグ）のブックマーク件数の取得
 *
 *  @access public
 *  @param  string  $keyword            キーワード
 *  @param  integer $user_id            ユーザID
 *  @param  integer $is_open_only       公開のみ表示フラグ
 */
function db_get_bookmarks_count4tag_keyword($keyword, $user_id = null, $is_open_only = true)
{
    //////////////////////////////////////////////
    // MySQL4.0.x 対応のためサブクエリは使用しない
    //////////////////////////////////////////////
    $word_list = array();

    if ($keyword)
    {
        $keyword = str_replace('　', ' ', $keyword);
        $word_list = explode(' ', $keyword);
    }

    // 認証判定
    if (pocket_isAuth())
    {
        $open_type = POCKET_SBS_OPEN_TYPE_INSIDE;
    }
    else {
        $open_type = POCKET_SBS_OPEN_TYPE_OPEN;
    }

    $sql = 'SELECT COUNT(DISTINCT(b.url_id))' .
            ' FROM psb_bookmarks AS b';

    foreach ($word_list as $key => $word)
    {
        $sql .= ', psb_tags AS t' . $key;
    }

    $sql .= ' WHERE 1 = 1';

    if ($user_id)
    {
        $sql .= ' AND b.user_id = ?';
        $params[] = intval($user_id);
    }

    if ($is_open_only)
    {
        $sql .= ' AND b.open_type >= ?';
        $params[] = $open_type;
    }

    foreach ($word_list as $key => $word)
    {
        $sql .= ' AND b.bookmark_id = t' . $key . '.bookmark_id';
    }

    foreach ($word_list as $key => $word)
    {
        $sql .= ' AND UPPER(t' . $key . '.tag) = UPPER(?)';
        $word = poket_db_replaceLikeWord($word);
        $params[] = $word;
    }

    return pocket_db_getOne($sql, $params);
}

/**
 *  キーワード検索（URL）のブックマーク一覧情報の取得
 *
 *  @access public
 *  @param  string  $keyword            キーワード
 *  @param  integer $user_id            ユーザID
 *  @param  integer $is_open_only       公開のみ表示フラグ
 *  @param  integer $page               ページ番号
 *  @param  integer $page_size          ページサイズ
 */
function db_get_bookmarks4url_keyword($keyword, $user_id = null, $is_open_only = true, $page = 1, $page_size = 5)
{
    //////////////////////////////////////////////
    // MySQL4.0.x 対応のためサブクエリは使用しない
    //////////////////////////////////////////////
    // 認証判定
    if (pocket_isAuth())
    {
        $open_type = POCKET_SBS_OPEN_TYPE_INSIDE;
    }
    else {
        $open_type = POCKET_SBS_OPEN_TYPE_OPEN;
    }

    // DB種別の判定
    if (pocket_db_isMySQL())
    {
        $sql = 'SELECT DISTINCT b.url_id AS url_id' .
                ' FROM psb_bookmarks AS b, psb_urls AS u' .
                ' WHERE b.url_id = u.url_id';

        if ($user_id)
        {
            $sql .= ' AND b.user_id = ?';
            $params[] = intval($user_id);
        }

        if ($is_open_only)
        {
            $sql .= ' AND b.open_type >= ?';
            $params[] = $open_type;
        }

        if ($keyword)
        {
            $sql .= ' AND u.url LIKE ?';
            $keyword = poket_db_replaceLikeWord($keyword);
            $params[] = $keyword . '%';
        }

        $sql .= ' ORDER BY b.r_datetime DESC';
    }
    else
    {
        $sql = 'SELECT url_id FROM psb_urls WHERE url_id IN (';

        $sql .= ' SELECT DISTINCT b.url_id AS url_id' .
                ' FROM psb_bookmarks AS b, psb_urls AS u' .
                ' WHERE b.url_id = u.url_id';

        if ($user_id)
        {
            $sql .= ' AND b.user_id = ?';
            $params[] = intval($user_id);
        }

        if ($is_open_only)
        {
            $sql .= ' AND b.open_type >= ?';
            $params[] = $open_type;
        }

        if ($keyword)
        {
            $sql .= ' AND u.url LIKE ?';
            $keyword = poket_db_replaceLikeWord($keyword);
            $params[] = $keyword . '%';
        }

        $sql .= ' ) ORDER BY m_datetime DESC';
    }

    $list = pocket_db_getAllPage($sql, $page, $page_size, $params);
    foreach ($list as $key => $item)
    {
        if ($user_id)
        {
            $bookmark_info = db_get_bookmark4user_url_id($user_id, $item['url_id']);
            $list[$key]['tags_list'] = db_get_tags4bookmark_id($bookmark_info['bookmark_id']);
        }
        else {
            $bookmark_info = db_get_bookmark4latest_info($item['url_id']);
            $list[$key]['tags_list'] = db_get_tags4url_id($item['url_id']);
        }
        $list[$key]['bookmark_id']  = $bookmark_info['bookmark_id'];
        $list[$key]['user_id']      = $bookmark_info['user_id'];
        $list[$key]['nickname']     = $bookmark_info['nickname'];
        $list[$key]['url']          = $bookmark_info['url'];
        $list[$key]['subject']      = $bookmark_info['subject'];
        $list[$key]['explanation']  = $bookmark_info['explanation'];
        $list[$key]['open_type']    = $bookmark_info['open_type'];
        $list[$key]['r_datetime']   = $bookmark_info['r_datetime'];
        $list[$key]['user_count']   = db_get_bookmark_user_count4url_id($item['url_id']);
    }
    return $list;
}

/**
 *  キーワード検索（URL）のブックマーク件数の取得
 *
 *  @access public
 *  @param  string  $keyword            キーワード
 *  @param  integer $user_id            ユーザID
 *  @param  integer $is_open_only       公開のみ表示フラグ
 */
function db_get_bookmarks_count4url_keyword($keyword, $user_id = null, $is_open_only = true)
{
    //////////////////////////////////////////////
    // MySQL4.0.x 対応のためサブクエリは使用しない
    //////////////////////////////////////////////
    // 認証判定
    if (pocket_isAuth())
    {
        $open_type = POCKET_SBS_OPEN_TYPE_INSIDE;
    }
    else {
        $open_type = POCKET_SBS_OPEN_TYPE_OPEN;
    }

    $sql = 'SELECT COUNT(DISTINCT(b.url_id))' .
            ' FROM psb_bookmarks AS b, psb_urls AS u' .
            ' WHERE b.url_id = u.url_id';

    if ($user_id)
    {
        $sql .= ' AND b.user_id = ?';
        $params[] = intval($user_id);
    }

    if ($is_open_only)
    {
        $sql .= ' AND b.open_type >= ?';
        $params[] = $open_type;
    }

    if ($keyword)
    {
        $sql .= ' AND u.url LIKE ?';
        $keyword = poket_db_replaceLikeWord($keyword);
        $params[] = $keyword . '%';
    }

    return pocket_db_getOne($sql, $params);
}

/**
 *  エクスポート用のブックマーク情報の取得
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 */
function db_get_bookmarks4export($user_id)
{
    //////////////////////////////////////////////
    // MySQL4.0.x 対応のためサブクエリは使用しない
    //////////////////////////////////////////////
    $sql = 'SELECT bookmark_id, user_id, url_id, subject, explanation, open_type, r_datetime, m_datetime' .
            ' FROM psb_bookmarks' .
            ' WHERE user_id = ?' .
            ' ORDER BY r_datetime DESC';
    $params = array(
        intval($user_id)
    );
    $list = pocket_db_getAll($sql, $params);
    foreach ($list as $key => $item)
    {
        $list[$key]['url']       = db_get_url_string($item['url_id']);
    }
    return $list;
}

/**
 *  URLをブックマーク（内部公開 or 外部公開）しているユーザ一覧情報の取得
 *
 *  @access public
 *  @param  integer $url_id             URLID
 *  @param  integer $page_size          ページサイズ
 */
function db_get_bookmark_user_list4url_id($url_id, $page_size = 0)
{
    //////////////////////////////////////////////
    // MySQL4.0.x 対応のためサブクエリは使用しない
    //////////////////////////////////////////////
    $sql = 'SELECT bookmark_id, user_id, r_datetime' .
            ' FROM psb_bookmarks' .
            ' WHERE url_id = ?' .
            '   AND open_type >= ?' .
            ' ORDER BY r_datetime DESC';
    $params = array(
        intval($url_id)
    );

    // 認証判定
    if (pocket_isAuth())
    {
        $params[] = POCKET_SBS_OPEN_TYPE_INSIDE;
    }
    else {
        $params[] = POCKET_SBS_OPEN_TYPE_OPEN;
    }

    if ($page_size)
    {
        $list = pocket_db_getAllPage($sql, 1, $page_size, $params);
    }
    else {
        $list = pocket_db_getAll($sql, $params);
    }
    foreach ($list as $key => $item)
    {
        $list[$key]['nickname']  = db_get_nickname4user_id($item['user_id']);
        $list[$key]['tags_list'] = db_get_tags4bookmark_id($item['bookmark_id']);
    }
    return $list;
}

/**
 *  URLをブックマーク（内部公開 or 外部公開）しているユーザ数の取得
 *
 *  @access public
 *  @param  integer $url_id             URLID
 */
function db_get_bookmark_user_count4url_id($url_id)
{
    $sql = 'SELECT count(user_id)' .
            ' FROM psb_bookmarks' .
            ' WHERE url_id = ?' .
            '   AND open_type >= ?';
    $params = array(
        intval($url_id)
    );

    // 認証判定
    if (pocket_isAuth())
    {
        $params[] = POCKET_SBS_OPEN_TYPE_INSIDE;
    }
    else {
        $params[] = POCKET_SBS_OPEN_TYPE_OPEN;
    }

    return pocket_db_getOne($sql, $params);
}

/**
 *  指定URLの最新ブックマーク（内部公開 or 外部公開）情報の取得
 *
 *  @access public
 *  @param  integer $url_id             URLID
 */
function db_get_bookmark4latest_info($url_id)
{
    //////////////////////////////////////////////
    // MySQL4.0.x 対応のためサブクエリは使用しない
    //////////////////////////////////////////////
    $sql = 'SELECT bookmark_id, user_id, subject, explanation, open_type, r_datetime' .
            ' FROM psb_bookmarks' .
            ' WHERE url_id = ?' .
            '   AND open_type >= ?' .
            ' ORDER BY r_datetime DESC';
    $params = array(
        intval($url_id)
    );

    // 認証判定
    if (pocket_isAuth())
    {
        $params[] = POCKET_SBS_OPEN_TYPE_INSIDE;
    }
    else {
        $params[] = POCKET_SBS_OPEN_TYPE_OPEN;
    }

    $result = pocket_db_getRow($sql, $params);
    if ($result)
    {
        $result['nickname'] = db_get_nickname4user_id($result['user_id']);
        $result['url']      = db_get_url_string($url_id);
    }
    return $result;
}

/**
 *  指定ユーザの指定URLのブックマーク情報（全公開区分）の取得
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 *  @param  integer $url_id             URLID
 */
function db_get_bookmark4user_url_id($user_id, $url_id)
{
    //////////////////////////////////////////////
    // MySQL4.0.x 対応のためサブクエリは使用しない
    //////////////////////////////////////////////
    $sql = 'SELECT bookmark_id, user_id, subject, explanation, open_type, r_datetime' .
            ' FROM psb_bookmarks' .
            ' WHERE user_id = ?' .
            ' AND url_id = ?';
    $params = array(
        intval($user_id),
        intval($url_id)
    );
    $result = pocket_db_getRow($sql, $params);
    if ($result)
    {
        $result['nickname'] = db_get_nickname4user_id($result['user_id']);
        $result['url']      = db_get_url_string($url_id);
    }
    return $result;
}

/**
 *  ブックマーク情報（全公開区分）の取得
 *
 *  @access public
 *  @param  integer $bookmark_id        ID
 */
function db_get_bookmark($bookmark_id)
{
    //////////////////////////////////////////////
    // MySQL4.0.x 対応のためサブクエリは使用しない
    //////////////////////////////////////////////
    $sql = 'SELECT bookmark_id, user_id, url_id, subject, explanation, open_type, r_datetime, m_datetime' .
            ' FROM psb_bookmarks' .
            ' WHERE bookmark_id = ?';
    $params = array(
        intval($bookmark_id)
    );
    $row = pocket_db_getRow($sql, $params);
    if ($row)
    {
        $row['nickname']     = db_get_nickname4user_id($row['user_id']);
        $row['url']          = db_get_url_string($row['url_id']);
        $row['user_count']   = db_get_bookmark_user_count4url_id($row['url_id']);
        $row['tags']         = db_get_tags_string4user_bookmark_id($row['user_id'], $row['bookmark_id']);
    }
    return $row;
}

/**
 *  ブックマーク情報の登録
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 *  @param  integer $url                URL
 *  @param  string  $subject            タイトル
 *  @param  string  $explanation        説明
 *  @param  string  $tags               タグ
 *  @param  integer $open_type          公開区分
 */
function db_insert_bookmark($user_id, $url, $subject, $explanation, $tags, $open_type)
{
    $url_id = db_get_url_id4url($url);
    if (!$url_id)
    {
        $url_id = db_insert_url($url);
    }
    else
    {
        db_update_url4m_datetime($url);
    }

    $data = array(
        'user_id' => intval($user_id),
        'url_id' => intval($url_id),
        'subject' => $subject,
        'explanation' => $explanation,
        'open_type' => intval($open_type),
        'r_datetime' => pocket_db_getNow(),
        'm_datetime' => pocket_db_getNow()
    );
    $bookmark_id = pocket_db_insert('psb_bookmarks', $data, 'psb_bookmarks_bookmark_id_seq');
    if ($bookmark_id)
    {
        db_insert_tags($bookmark_id, $user_id, $url_id, $tags);
    }
    return $bookmark_id;
}

/**
 *  ブックマーク情報の更新
 *
 *  @access public
 *  @param  integer $bookmark_id        ID
 *  @param  integer $user_id            ユーザID
 *  @param  integer $url_id             URLID
 *  @param  string  $subject            タイトル
 *  @param  string  $explanation        説明
 *  @param  string  $tags               タグ
 *  @param  integer $open_type          公開区分
 */
function db_update_bookmark($bookmark_id, $user_id, $url_id, $subject, $explanation, $tags, $open_type)
{
    $data = array(
        'subject' => $subject,
        'explanation' => $explanation,
        'open_type' => intval($open_type),
        'm_datetime' => pocket_db_getNow()
    );
    $where = array(
        'bookmark_id' => intval($bookmark_id)
    );
    $result = pocket_db_update('psb_bookmarks', $data, $where);
    if ($result)
    {
        db_insert_tags($bookmark_id, $user_id, $url_id, $tags);
    }
    return $result;
}

/**
 *  ブックマーク情報の削除
 *
 *  @access public
 *  @param  integer $bookmark_id        ID
 */
function db_delete_bookmark($bookmark_id)
{
    // URLIDの取得
    $sql = 'SELECT url_id' .
            ' FROM psb_bookmarks' .
            ' WHERE bookmark_id = ?';
    $params = array(
        intval($bookmark_id)
    );
    $url_id = pocket_db_getOne($sql, $params);
    if (!$url_id) {return false;}

    // ブックマーク情報の削除
    if (!db_delete_tag4bookmark_id($bookmark_id)) {return false;}
    $result = pocket_db_delete('psb_bookmarks', 'bookmark_id', intval($bookmark_id));

    if ($result)
    {
        // URL情報の削除
        $sql = 'LOCK TABLES psb_bookmarks WRITE, psb_urls WRITE, psb_url_keywords WRITE';
        pocket_db_query($sql);

        if (!db_is_exist_bookmark4url_id($url_id))
        {
            db_delete_url($url_id);
        }

        $sql = 'UNLOCK TABLES';
        pocket_db_query($sql);
    }

    return $result;
}

/**
 *  ブックマーク情報の削除
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 */
function db_delete_bookmark4user_id($user_id)
{
    // URLIDの取得
    $sql = 'SELECT url_id' .
            ' FROM psb_bookmarks' .
            ' WHERE user_id = ?';
    $params = array(
        intval($user_id)
    );
    $cols = pocket_db_getCol($sql, $params);

    // 一件も登録されていない場合は、正常終了
    if (!$cols) {return true;}

    // ブックマーク情報の削除
    if (!db_delete_tag4user_id($user_id)) {return false;}
    $result = pocket_db_delete('psb_bookmarks', 'user_id', intval($user_id));

    if ($result)
    {
        // URL情報の削除
        $sql = 'LOCK TABLES psb_bookmarks WRITE, psb_urls WRITE, psb_url_keywords WRITE';
        pocket_db_query($sql);

        foreach ($cols as $key => $item)
        {
            if (!db_is_exist_bookmark4url_id($item))
            {
                db_delete_url($item);
            }
        }

        $sql = 'UNLOCK TABLES';
        pocket_db_query($sql);
    }

    return $result;
}

/**
 *  ブックマーク情報の削除
 *
 *  @access public
 *  @param  integer $url_id             URLID
 */
function db_delete_bookmark4url_id($url_id)
{
    // URLをブックマーク（公開）しているユーザ一覧情報の取得
    $list = db_get_bookmark_user_list4url_id($url_id);

    foreach ($list as $key => $item)
    {
        // ブックマーク情報の削除
        $result = db_delete_bookmark($item['bookmark_id']);
    }

    return $result;
}

/**
 *  ユーザのブックマーク（URL）の存在チェック
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 *  @param  string  $url                URL
 */
function db_is_exist_bookmark4user_url($user_id, $url)
{
    $url_id = db_get_url_id4url($url);
    if (!$url_id) {return false;}

    $sql = 'SELECT bookmark_id' .
            ' FROM psb_bookmarks' .
            ' WHERE user_id = ?' .
            '   AND url_id = ?';
    $params = array(
        intval($user_id),
        intval($url_id)
    );
    return (bool)pocket_db_getOne($sql, $params);
}

/**
 *  ブックマーク（URL）の存在チェック
 *
 *  @access public
 *  @param  integer $url_id             ID
 */
function db_is_exist_bookmark4url_id($url_id)
{
    $sql = 'SELECT bookmark_id' .
            ' FROM psb_bookmarks' .
            ' WHERE url_id = ?';
    $params = array(
        intval($url_id)
    );
    return (bool)pocket_db_getOne($sql, $params);
}

?>
