<?php
/**
 * Pocket Project
 * 
 * @copyright 2007 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  人気のタグ情報（内部公開 or 外部公開）の取得
 *
 *  @access public
 *  @param  integer $page_size          ページサイズ
 */
function db_get_tags4pop($page_size = 10)
{
    //////////////////////////////////////////////
    // MySQL4.0.x 対応のためサブクエリは使用しない
    //////////////////////////////////////////////
    $sql = 'SELECT t.tag, COUNT(t.tag_id) AS count' .
            ' FROM psb_bookmarks AS b, psb_tags AS t' .
            ' WHERE b.open_type >= ?' .
            '   AND b.bookmark_id = t.bookmark_id' .
            ' GROUP BY t.tag';

    // 認証判定
    if (pocket_isAuth())
    {
        $params[] = POCKET_SBS_OPEN_TYPE_INSIDE;
    }
    else {
        $params[] = POCKET_SBS_OPEN_TYPE_OPEN;
    }

    // DB種別の判定
    if (pocket_db_isMySQL())
    {
        $sql .= ' ORDER BY RAND()';
    }
    else {
        $sql .= ' ORDER BY RANDOM()';
    }

    return pocket_db_getAllPage($sql, 1, $page_size, $params);
}

/**
 *  全てのタグ情報（内部公開 or 外部公開）の取得
 *
 *  @access public
 */
function db_get_tags4all()
{
    //////////////////////////////////////////////
    // MySQL4.0.x 対応のためサブクエリは使用しない
    //////////////////////////////////////////////
    $sql = 'SELECT t.tag, COUNT(t.tag_id) AS count' .
            ' FROM psb_bookmarks AS b, psb_tags AS t' .
            ' WHERE b.open_type >= ?' .
            '   AND b.bookmark_id = t.bookmark_id' .
            ' GROUP BY t.tag';

    // 認証判定
    if (pocket_isAuth())
    {
        $params[] = POCKET_SBS_OPEN_TYPE_INSIDE;
    }
    else {
        $params[] = POCKET_SBS_OPEN_TYPE_OPEN;
    }

    // DB種別の判定
    if (pocket_db_isMySQL())
    {
        $sql .= ' ORDER BY RAND()';
    }
    else {
        $sql .= ' ORDER BY RANDOM()';
    }

    return pocket_db_getAll($sql, $params);
}

/**
 *  指定URLのタグ情報（内部公開 or 外部公開）の取得
 *
 *  @access public
 *  @param  integer $url_id             URLID
 */
function db_get_tags4url_id($url_id)
{
    //////////////////////////////////////////////
    // MySQL4.0.x 対応のためサブクエリは使用しない
    //////////////////////////////////////////////
    $sql = 'SELECT t.tag' .
            ' FROM psb_bookmarks AS b, psb_tags AS t' .
            ' WHERE b.url_id = ?' .
            '   AND b.open_type >= ?' .
            '   AND b.bookmark_id = t.bookmark_id' .
            ' GROUP BY t.tag' .
            ' ORDER BY t.tag';
    $params = array(
        intval($url_id)
    );

    // 認証判定
    if (pocket_isAuth())
    {
        $params[] = POCKET_SBS_OPEN_TYPE_INSIDE;
    }
    else {
        $params[] = POCKET_SBS_OPEN_TYPE_OPEN;
    }

    return pocket_db_getCol($sql, $params);
}

/**
 *  指定URLのタグ情報（内部公開 or 外部公開）の取得
 *
 *  @access public
 *  @param  string  $url                URL
 */
function db_get_tags4url($url)
{
    $url_id = db_get_url_id4url($url);
    if ($url_id)
    {
        $result = db_get_tags4url_id($url_id);
    }
    return $result;
}

/**
 *  指定ブックマークのタグ情報（内部公開 or 外部公開）の取得
 *
 *  @access public
 *  @param  integer $bookmark_id        ブックマークID
 */
function db_get_tags4bookmark_id($bookmark_id)
{
    //////////////////////////////////////////////
    // MySQL4.0.x 対応のためサブクエリは使用しない
    //////////////////////////////////////////////
    $sql = 'SELECT t.tag' .
            ' FROM psb_bookmarks AS b, psb_tags AS t' .
            ' WHERE b.bookmark_id = ?' .
            '   AND b.open_type >= ?' .
            '   AND b.bookmark_id = t.bookmark_id' .
            ' GROUP BY t.tag' .
            ' ORDER BY t.tag';
    $params = array(
        intval($bookmark_id)
    );

    // 認証判定
    if (pocket_isAuth())
    {
        $params[] = POCKET_SBS_OPEN_TYPE_INSIDE;
    }
    else {
        $params[] = POCKET_SBS_OPEN_TYPE_OPEN;
    }

    return pocket_db_getCol($sql, $params);
}

/**
 *  指定ユーザの指定ブックマークのタグ連結文字列（全公開区分）の取得
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 *  @param  integer $bookmark_id        ブックマークID
 */
function db_get_tags_string4user_bookmark_id($user_id, $bookmark_id)
{
    $sql = 'SELECT tag' .
            ' FROM psb_tags' .
            ' WHERE user_id = ?' .
            '   AND bookmark_id = ?' .
            ' GROUP BY tag' .
            ' ORDER BY tag';
    $params = array(
        intval($user_id),
        intval($bookmark_id)
    );
    $list = pocket_db_getCol($sql, $params);
    foreach ($list as $key => $item)
    {
        $tags .= $item . " ";
    }
    return $tags;
}

/**
 *  指定ユーザのタグ情報（全公開区分）の取得
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 */
function db_get_tags4user_id($user_id)
{
    $sql = 'SELECT tag, COUNT(tag_id) AS count' .
            ' FROM psb_tags' .
            ' WHERE user_id = ?' .
            ' GROUP BY tag' .
            ' ORDER BY tag';
    $params = array(
        intval($user_id)
    );
    return pocket_db_getAll($sql, $params);
}

/**
 *  ユーザのタグ件数（全公開区分）の取得
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 */
function db_get_tags_count4user_id($user_id)
{
    $sql = 'SELECT count(distinct(tag))' .
            ' FROM psb_tags' .
            ' WHERE user_id = ?';
    $params = array(
        intval($user_id)
    );
    return pocket_db_getOne($sql, $params);
}

/**
 *  タグ情報の登録
 *
 *  @access public
 *  @param  integer $bookmark_id        ブックマークID
 *  @param  integer $user_id            ユーザID
 *  @param  integer $url_id             URLID
 *  @param  string  $tag                タグ
 */
function db_insert_tag($bookmark_id, $user_id, $url_id, $tag)
{
    $data = array(
        'bookmark_id' => intval($bookmark_id),
        'user_id' => intval($user_id),
        'url_id' => intval($url_id),
        'tag' => $tag,
        'r_datetime' => pocket_db_getNow()
    );
    return pocket_db_insert('psb_tags', $data, 'psb_tags_tag_id_seq');
}

/**
 *  タグ情報（複数件）の登録
 *
 *  @access public
 *  @param  integer $bookmark_id        ブックマークID
 *  @param  integer $user_id            ユーザID
 *  @param  integer $url_id             URLID
 *  @param  string  $tags               タグ
 */
function db_insert_tags($bookmark_id, $user_id, $url_id, $tags)
{
    db_delete_tag4bookmark_id($bookmark_id);
    $tags = str_replace('　', ' ', $tags);
    $list = explode(' ', trim($tags));
    foreach ($list as $key => $item)
    {
        if ($item) db_insert_tag($bookmark_id, $user_id, $url_id, $item);
    }
}

/**
 *  タグ情報の削除
 *
 *  @access public
 *  @param  integer $bookmark_id        ブックマークID
 */
function db_delete_tag4bookmark_id($bookmark_id)
{
    return pocket_db_delete('psb_tags', 'bookmark_id', intval($bookmark_id));
}

/**
 *  タグ情報の削除
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 */
function db_delete_tag4user_id($user_id)
{
    return pocket_db_delete('psb_tags', 'user_id', intval($user_id));
}

?>
