<?php
/**
 * Pocket Project
 * 
 * @copyright 2007 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  URL情報の取得
 *
 *  @access public
 *  @param  integer $url_id             ID
 */
function db_get_url($url_id)
{
    $sql = 'SELECT url_id, url, is_thumbnail, r_datetime, m_datetime' .
            ' FROM psb_urls' .
            ' WHERE url_id = ?';
    $params = array(
        intval($url_id)
    );
    return pocket_db_getRow($sql, $params);
}

/**
 *  URL情報（サムネイル用）の取得
 *
 *  @access public
 *  @param  integer $page_size          ページサイズ
 */
function db_get_url4thumbnail($page_size = 5)
{
    $sql = 'SELECT url_id, url' .
            ' FROM psb_urls' .
            ' WHERE is_thumbnail = ?' .
            ' ORDER BY url_id';
    $params = array(
        intval(false)
    );
    return pocket_db_getAllPage($sql, 1, $page_size, $params);
}

/**
 *  URLIDの取得
 *
 *  @access public
 *  @param  string  $url                URL
 */
function db_get_url_id4url($url)
{
    $sql = 'SELECT url_id' .
            ' FROM psb_urls' .
            ' WHERE url = ?';
    $params = array(
        $url
    );
    return pocket_db_getOne($sql, $params);
}

/**
 *  URL文字列の取得
 *
 *  @access public
 *  @param  integer $url_id             ID
 */
function db_get_url_string($url_id)
{
    $sql = 'SELECT url' .
            ' FROM psb_urls' .
            ' WHERE url_id = ?';
    $params = array(
        intval($url_id)
    );
    return pocket_db_getOne($sql, $params);
}

/**
 *  URL情報の登録
 *
 *  @access public
 *  @param  string  $url                URL
 */
function db_insert_url($url)
{
    $data = array(
        'url' => $url,
        'is_thumbnail' => intval(false),
        'r_datetime' => pocket_db_getNow(),
        'm_datetime' => pocket_db_getNow()
    );
    return pocket_db_insert('psb_urls', $data, 'psb_urls_url_id_seq');
}

/**
 *  URL情報の更新（サムネイルフラグ）
 *
 *  @access public
 *  @param  integer $url_id             ID
 *  @param  integer $is_thumbnail       サムネイルフラグ
 */
function db_update_url4is_thumbnail($url_id, $is_thumbnail)
{
    $data = array(
        'is_thumbnail' => intval($is_thumbnail)
    );
    $where = array(
        'url_id' => $url_id
    );
    return pocket_db_update('psb_urls', $data, $where);
}

/**
 *  URL情報の更新（更新日）
 *
 *  @access public
 *  @param  string  $url                URL
 */
function db_update_url4m_datetime($url)
{
    $data = array(
        'm_datetime' => pocket_db_getNow()
    );
    $where = array(
        'url' => $url
    );
    return pocket_db_update('psb_urls', $data, $where);
}

/**
 *  URL情報の削除
 *
 *  @access public
 *  @param  integer $url_id             ID
 */
function db_delete_url($url_id)
{
    return pocket_db_delete('psb_urls', 'url_id', intval($url_id));
}

/**
 *  URL情報の削除
 *
 *  @access public
 *  @param  string  $url                URL
 */
function db_delete_url4url($url)
{
    $url_id = db_get_url_id4url($url);
    if (!$url_id) {return false;}
    return db_delete_url($url_id);
}

/**
 *  URLの存在チェック
 *
 *  @access public
 *  @param  string  $url                URL
 */
function db_is_exist_url4url($url)
{
    $sql = 'SELECT url_id' .
            ' FROM psb_urls' .
            ' WHERE url = ?';
    $params = array(
        $url
    );
    return (bool)pocket_db_getOne($sql, $params);
}

?>
