<?php
/**
 * Pocket Project
 * 
 * @copyright 2007 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  初期登録ユーザのIDの取得
 *
 *  @access public
 */
function db_get_user4first_user_id()
{
    $sql = 'SELECT user_id' .
            ' FROM psb_user' .
            ' ORDER BY r_datetime';
    return pocket_db_getOne($sql);
}

/**
 *  ユーザID情報の取得
 *
 *  @access public
 *  @param  integer $id                 ID
 */
function db_get_user_id($id)
{
    $sql = 'SELECT user_id' .
            ' FROM psb_user' .
            ' WHERE id = ?';
    $params = array(
        $id
    );
    return pocket_db_getOne($sql, $params);
}

/**
 *  ユーザID情報の取得
 *
 *  @access public
 *  @param  string  $easy_login_id      簡単ログインID
 */
function db_get_user_id4easy_login_id($easy_login_id)
{
    $sql = 'SELECT user_id' .
            ' FROM psb_user' .
            ' WHERE easy_login_id = ?' .
            ' AND allow_login = ?';
    $params = array(
        $easy_login_id,
        intval(true)
    );
    return pocket_db_getOne($sql, $params);
}

/**
 *  ニックネーム情報の取得
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 */
function db_get_nickname4user_id($user_id)
{
    $sql = 'SELECT nickname' .
            ' FROM psb_user' .
            ' WHERE user_id = ?';
    $params = array(
        intval($user_id)
    );
    return pocket_db_getOne($sql, $params);
}

/**
 *  ユーザ情報の取得
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 */
function db_get_user($user_id)
{
    $sql = 'SELECT user_id, id, email, easy_login_id, nickname, default_open_type, simple_indication,' .
                ' target_blank, bookmark_size, allow_login, r_datetime, m_datetime' .
            ' FROM psb_user' .
            ' WHERE user_id = ?';
    $params = array(
        intval($user_id)
    );
    return pocket_db_getRow($sql, $params);
}

/**
 *  ユーザ一覧情報の取得
 *
 *  @access public
 *  @param  string  $id                 ID
 *  @param  string  $email              メールアドレス
 *  @param  integer $page               ページ番号
 *  @param  integer $page_size          ページサイズ
 */
function db_get_users4user_list($id, $email, $page = 1, $page_size = 5)
{
    $sql = 'SELECT user_id, id, email, easy_login_id, nickname, default_open_type, simple_indication,' .
                ' target_blank, bookmark_size, allow_login, r_datetime, m_datetime' .
            ' FROM psb_user' .
            ' WHERE user_id <> ?';
    $params = array(
        intval(db_get_user4first_user_id())
    );

    if ($id)
    {
        $sql .= ' AND id LIKE ?';
        $id = poket_db_replaceLikeWord($id);
        $params[] = $id . '%';
    }
    if ($email)
    {
        $sql .= ' AND email = ?';
        $params[] = $email;
    }

    $sql .= ' ORDER BY id';

    return pocket_db_getAllPage($sql, $page, $page_size, $params);
}

/**
 *  ユーザ一覧情報の件数の取得
 *
 *  @access public
 *  @param  string  $id                 ID
 *  @param  string  $email              メールアドレス
 */
function db_get_users_count4user_list($id, $email)
{
    $sql = 'SELECT count(user_id)' .
            ' FROM psb_user' .
            ' WHERE user_id <> ?';
    $params = array(
        intval(db_get_user4first_user_id())
    );

    if ($id)
    {
        $sql .= ' AND id LIKE ?';
        $id = poket_db_replaceLikeWord($id);
        $params[] = $id . '%';
    }
    if ($email)
    {
        $sql .= ' AND email = ?';
        $params[] = $email;
    }

    return pocket_db_getOne($sql, $params);
}

/**
 *  ユーザ情報の登録
 *
 *  @access public
 *  @param  string  $id                 ID
 *  @param  string  $nickname           ニックネーム
 *  @param  integer $bookmark_size      ブックマークの表示件数
 */
function db_insert_userEasyProfile($id, $nickname, $bookmark_size = 10)
{
    $data = array(
        'id' => $id,
        'nickname' => $nickname,
        'default_open_type' => POCKET_SBS_OPEN_TYPE_OPEN,
        'simple_indication' => intval(false),
        'target_blank' => intval(false),
        'bookmark_size' => intval($bookmark_size),
        'allow_login' => intval(true),
        'r_datetime' => pocket_db_getNow(),
        'm_datetime' => pocket_db_getNow()
    );
    return pocket_db_insert('psb_user', $data, 'psb_user_user_id_seq');
}

/**
 *  ユーザ情報の登録
 *
 *  @access public
 *  @param  string  $id                 ID
 *  @param  string  $email              メールアドレス
 *  @param  string  $password           パスワード
 *  @param  string  $nickname           ニックネーム
 *  @param  string  $default_open_type  デフォルト公開区分
 *  @param  string  $simple_indication  エントリーの簡易表示フラグ
 *  @param  string  $target_blank       別ウィンドウ表示フラグ
 *  @param  integer $bookmark_size      ブックマークの表示件数
 *  @param  string  $allow_login        ログイン許可フラグ
 */
function db_insert_user($id, $email, $password, $nickname, $default_open_type, $simple_indication,
                        $target_blank, $bookmark_size, $allow_login)
{
    $data = array(
        'id' => $id,
        'email' => $email,
        'password' => $password,
        'nickname' => $nickname,
        'default_open_type' => intval($default_open_type),
        'simple_indication' => intval($simple_indication),
        'target_blank' => intval($target_blank),
        'bookmark_size' => intval($bookmark_size),
        'allow_login' => intval($allow_login),
        'r_datetime' => pocket_db_getNow(),
        'm_datetime' => pocket_db_getNow()
    );
    return pocket_db_insert('psb_user', $data, 'psb_user_user_id_seq');
}

/**
 *  ユーザ情報の更新
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 *  @param  string  $id                 ID
 *  @param  string  $email              メールアドレス
 *  @param  string  $nickname           ニックネーム
 *  @param  string  $default_open_type  デフォルト公開区分
 *  @param  string  $simple_indication  エントリーの簡易表示フラグ
 *  @param  string  $target_blank       別ウィンドウ表示フラグ
 *  @param  integer $bookmark_size      ブックマークの表示件数
 *  @param  string  $allow_login        ログイン許可フラグ
 */
function db_update_user($user_id, $id, $email, $nickname, $default_open_type, $simple_indication,
                        $target_blank, $bookmark_size, $allow_login)
{
    $data = array(
        'id' => $id,
        'email' => $email,
        'nickname' => $nickname,
        'default_open_type' => intval($default_open_type),
        'simple_indication' => intval($simple_indication),
        'target_blank' => intval($target_blank),
        'bookmark_size' => intval($bookmark_size),
        'allow_login' => intval($allow_login),
        'm_datetime' => pocket_db_getNow()
    );
    $where = array(
        'user_id' => intval($user_id)
    );
    return pocket_db_update('psb_user', $data, $where);
}

/**
 *  ユーザプロフィール情報の更新
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 *  @param  string  $nickname           ニックネーム
 *  @param  string  $default_open_type  デフォルト公開区分
 *  @param  string  $simple_indication  エントリーの簡易表示フラグ
 *  @param  string  $target_blank       別ウィンドウ表示フラグ
 *  @param  integer $bookmark_size      ブックマークの表示件数
 */
function db_update_userProfile($user_id, $nickname, $default_open_type, $simple_indication, $target_blank, $bookmark_size)
{
    $data = array(
        'nickname' => $nickname,
        'default_open_type' => intval($default_open_type),
        'simple_indication' => intval($simple_indication),
        'target_blank' => intval($target_blank),
        'bookmark_size' => intval($bookmark_size),
        'm_datetime' => pocket_db_getNow()
    );
    $where = array(
        'user_id' => intval($user_id)
    );
    return pocket_db_update('psb_user', $data, $where);
}

/**
 *  メールアドレス情報の更新
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 *  @param  string  $email              メールアドレス
 */
function db_update_userEmail($user_id, $email)
{
    $data = array(
        'email' => $email,
        'm_datetime' => pocket_db_getNow()
    );
    $where = array(
        'user_id' => intval($user_id)
    );
    return pocket_db_update('psb_user', $data, $where);
}

/**
 *  パスワード情報の更新
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 *  @param  string  $password           パスワード
 */
function db_update_userPassword($user_id, $password)
{
    $data = array(
        'password' => $password,
        'm_datetime' => pocket_db_getNow()
    );
    $where = array(
        'user_id' => intval($user_id)
    );
    return pocket_db_update('psb_user', $data, $where);
}

/**
 *  固体識別番号情報の更新
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 *  @param  string  $easy_login_id      固体識別番号
 */
function db_update_userEasyLoginId($user_id, $easy_login_id)
{
    $data = array(
        'easy_login_id' => $easy_login_id,
        'm_datetime' => pocket_db_getNow()
    );
    $where = array(
        'user_id' => intval($user_id)
    );
    return pocket_db_update('psb_user', $data, $where);
}

/**
 *  ユーザ情報の削除
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 */
function db_delete_user($user_id)
{
    if (!db_delete_bookmark4user_id($user_id)) {return false;}
    return pocket_db_delete('psb_user', 'user_id', intval($user_id));
}

/**
 *  ユーザ（ID）の存在チェック
 *
 *  @access public
 *  @param  string  $id                 ID
 */
function db_is_exist_user4id($id)
{
    $sql = 'SELECT user_id' .
            ' FROM psb_user' .
            ' WHERE id = ?';
    $params = array(
        $id
    );
    return (bool)pocket_db_getOne($sql, $params);
}

/**
 *  ユーザ（ID）の存在チェック（自分以外）
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 *  @param  string  $id                 ID
 */
function db_is_exist_user4another_person_id($user_id, $id)
{
    $sql = 'SELECT user_id' .
            ' FROM psb_user' .
            ' WHERE user_id <> ?' .
            ' AND id = ?';
    $params = array(
        intval($user_id),
        $id
    );
    return (bool)pocket_db_getOne($sql, $params);
}

/**
 *  ユーザ（メールアドレス）の存在チェック
 *
 *  @access public
 *  @param  string  $email              メールアドレス
 */
function db_is_exist_user4email($email)
{
    $sql = 'SELECT user_id' .
            ' FROM psb_user' .
            ' WHERE email = ?';
    $params = array(
        $email
    );
    return (bool)pocket_db_getOne($sql, $params);
}

/**
 *  ユーザ（メールアドレス）の存在チェック（自分以外）
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 *  @param  string  $email              メールアドレス
 */
function db_is_exist_user4another_person_email($user_id, $email)
{
    $sql = 'SELECT user_id' .
            ' FROM pr_user' .
            ' WHERE user_id <> ?' .
            ' AND email = ?';
    $params = array(
        intval($user_id),
        $email
    );
    return (bool)pocket_db_getOne($sql, $params);
}

/**
 *  メールアドレス認証
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 *  @param  string  $email              メールアドレス
 */
function db_auth_user4email($user_id, $email)
{
    $sql = 'SELECT user_id' .
            ' FROM psb_user' .
            ' WHERE user_id = ?' .
            ' AND email = ?' .
            ' AND allow_login = ?';
    $params = array(
        intval($user_id),
        $email,
        intval(true)
    );
    return (bool)pocket_db_getOne($sql, $params);
}

/**
 *  パスワード認証
 *
 *  @access public
 *  @param  integer $user_id            ユーザID
 *  @param  string  $password           パスワード
 */
function db_auth_user4password($user_id, $password)
{
    $sql = 'SELECT user_id' .
            ' FROM psb_user' .
            ' WHERE user_id = ?' .
            ' AND password = ?' .
            ' AND allow_login = ?';
    $params = array(
        intval($user_id),
        $password,
        intval(true)
    );
    return (bool)pocket_db_getOne($sql, $params);
}

?>
