<?php
/**
 * Pocket Project
 * 
 * @copyright 2007 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  ユーザ情報登録用のActionクラス
 *
 *  @author     Shogo Minami
 *  @access     public
 *  @package    PocketSBS.admin.do
 */
class userInsertAction extends Pocket_Sbs_Action
{
    /**
     *  アクション実行
     *
     *  @access public
     *  @param  object  $controller         コントローラ
     *  @param  object  $request            リクエスト情報
     *  @return string  success,error
     */
    function execute(&$controller, &$request)
    {
        // リクエスト情報の取得
        $id                = $request['id'];
        $email             = $request['email'];
        $password          = $request['password'];
        $nickname          = $request['nickname'];
        $default_open_type = $request['default_open_type'];
        $simple_indication = $request['simple_indication'];
        $target_blank      = $request['target_blank'];
        $bookmark_size     = $request['bookmark_size'];
        $allow_login       = $request['allow_login'];

        // ユーザの登録
        db_insert_user(
            $id,
            pocket_encrypt($email, POCKET_SBS_ENCRYPT_KEY),
            md5($password),
            $nickname,
            $default_open_type,
            $simple_indication,
            $target_blank,
            $bookmark_size,
            $allow_login
        );

        // メッセージの作成
        $params = array('msg' => 'ユーザを登録しました。');

        // リダイレクト
        pocket_redirect('userEntry.view', $params);
    }

    /**
     *  リクエスト検証
     *
     *  @access public
     *  @param  object  $validator          バリデータ
     *  @param  object  $request            リクエスト情報
     */
    function validate(&$validator, &$request)
    {
        // リクエスト情報の取得
        $id                = $request['id'];
        $email             = $request['email'];
        $password          = $request['password'];
        $nickname          = $request['nickname'];
        $default_open_type = $request['default_open_type'];
        $simple_indication = $request['simple_indication'];
        $target_blank      = $request['target_blank'];
        $bookmark_size     = $request['bookmark_size'];
        $allow_login       = $request['allow_login'];

        // エラー表示用のAction名称の設定
        $this->viewAction = 'userEntry';

        // 検証
        $validator->validate('id'           , 'ユーザID'      , $id           , 'string'                , true);
        $validator->validate('email'        , 'メールアドレス', $email        , 'email'                 , true);
        $validator->validate('password'     , 'パスワード'    , $password     , 'alnum'                 , true);
        $validator->validate('nickname'     , 'ニックネーム'  , $nickname     , 'string'                , true);

        // ユーザ（ID）の存在チェック
        if (db_is_exist_user4id($id))
        {
            $validator->addErrors('id', '指定されたIDは既に登録されています。');
        }

        // ユーザ（メールアドレス）の存在チェック
        if (db_is_exist_user4email(pocket_encrypt($email, POCKET_SBS_ENCRYPT_KEY)))
        {
            $validator->addErrors('email', '指定されたメールアドレスは既に登録されています。');
        }

        // パスワードの桁数チェック
        if (strlen($password) < 6 || strlen($password) > 12)
        {
            $validator->addErrors('password', 'パスワードの桁数が不正です。');
        }
    }
}

?>
