<?php
/**
 * Pocket Project
 * 
 * @copyright 2007 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  ユーザ情報更新用のActionクラス
 *
 *  @author     Shogo Minami
 *  @access     public
 *  @package    PocketSBS.admin.do
 */
class userUpdateAction extends Pocket_Sbs_Action
{
    /**
     *  アクション実行
     *
     *  @access public
     *  @param  object  $controller         コントローラ
     *  @param  object  $request            リクエスト情報
     *  @return string  success,error
     */
    function execute(&$controller, &$request)
    {
        // リクエスト情報の取得
        $user_id           = $request['user_id'];
        $id                = $request['id'];
        $email             = $request['email'];
        $nickname          = $request['nickname'];
        $default_open_type = $request['default_open_type'];
        $simple_indication = $request['simple_indication'];
        $target_blank      = $request['target_blank'];
        $bookmark_size     = $request['bookmark_size'];
        $allow_login       = $request['allow_login'];
        $referer           = $request['referer'];

        // ユーザの更新
        db_update_user(
            $user_id,
            $id,
            pocket_encrypt($email, POCKET_SBS_ENCRYPT_KEY),
            $nickname,
            $default_open_type,
            $simple_indication,
            $target_blank,
            $bookmark_size,
            $allow_login
        );

        // メッセージの作成
        $params = array('msg' => 'ユーザを更新しました。');

        // リファラの存在チェック
        if ($referer)
        {
            // 指定URLへリダイレクト
            pocket_redirect4location($referer);
        }
        else {
            // ユーザ一覧へリダイレクト
            pocket_redirect('user.view', $params);
        }
    }

    /**
     *  リクエスト検証
     *
     *  @access public
     *  @param  object  $validator          バリデータ
     *  @param  object  $request            リクエスト情報
     */
    function validate(&$validator, &$request)
    {
        // リクエスト情報の取得
        $user_id           = $request['user_id'];
        $id                = $request['id'];
        $email             = $request['email'];
        $nickname          = $request['nickname'];
        $default_open_type = $request['default_open_type'];
        $simple_indication = $request['simple_indication'];
        $target_blank      = $request['target_blank'];
        $bookmark_size     = $request['bookmark_size'];
        $allow_login       = $request['allow_login'];
        $referer           = $request['referer'];

        // エラー表示用のAction名称の設定
        $this->viewAction = 'userEdit';

        // 検証
        $validator->validate('user_id'      , 'ID'            , $user_id      , 'number'                , true);
        $validator->validate('id'           , 'ユーザID'      , $id           , 'string'                , true);
        $validator->validate('email'        , 'メールアドレス', $email        , 'email'                 , true);
        $validator->validate('nickname'     , 'ニックネーム'  , $nickname     , 'string'                , true);

        // ユーザ（ID）の存在チェック（自分以外）
        if (db_is_exist_user4another_person_id($user_id, $id))
        {
            $validator->addErrors('id', '指定されたIDは既に登録されています。');
        }

        // ユーザ（メールアドレス）の存在チェック（自分以外）
        if (db_is_exist_user4another_person_email($user_id, pocket_encrypt($email, POCKET_SBS_ENCRYPT_KEY)))
        {
            $validator->addErrors('email', '指定されたメールアドレスは既に登録されています。');
        }
    }
}

?>
