<?php
/**
 * Pocket Project
 * 
 * @copyright 2007 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  ブックマーク一覧画面表示用のActionクラス
 *
 *  @author     Shogo Minami
 *  @access     public
 *  @package    PocketSbs.mobile.view
 */
class bookmarkListAction extends Pocket_Sbs_Action
{
    /**
     *  アクション実行
     *
     *  @access public
     *  @param  object  $controller         コントローラ
     *  @param  object  $request            リクエスト情報
     *  @return string  success,error
     */
    function execute(&$controller, &$request)
    {
        // リクエスト情報の取得
        $target_user_id = $request['target_user_id'];
        $keyword        = $request['keyword'];
        $search_type    = $request['search_type'];
        $page           = $request['page'];

        /**
         *  メイン情報の取得、設定
         */
        // ブックマークの表示件数の取得
        if (pocket_isAuth())
        {
            $user = db_get_user($_SESSION['user_id']);
            $bookmark_size = $user['bookmark_size'];
        }
        else {
            $bookmark_size = PAGE_SIZE;
        }

        // キーワードの取得、設定
        $keyword = str_replace(" ", "　", $keyword);
        $this->assign('keyword', $keyword);

        // キーワードの半角カナを全角カナに変換
        if (function_exists('mb_convert_kana'))
            $keyword = mb_convert_kana($keyword, 'KV');

        // 検索タイプの設定
        $this->assign('search_type', $search_type);

        // ページ番号の取得
        $page = (empty($page)) ? 1 : $page;

        // ターゲットユーザIDの存在チェック
        if (!$target_user_id)
            $target_user_id = $_SESSION['user_id'];

        // ターゲットユーザIDの設定
        $this->assign('target_user_id', $target_user_id);

        // ユーザ情報の取得
        $user = db_get_user($target_user_id);

        // ユーザ情報の存在チェック
        if (!$user)
            pocket_redirect('default.view');

        // ユーザ情報の設定
        $this->assign('user', $user);

        // メンテナンス権限フラグの取得
        $is_maintenance = $this->isAllowMaintenance($target_user_id, false);

        // 検索タイプの判定
        switch ($search_type)
        {
        case "url":
            // キーワード検索（URL）のブックマーク一覧情報の取得、設定
            $this->assign('bookmarks', db_get_bookmarks4url_keyword($keyword, $target_user_id, !$is_maintenance, $page, $bookmark_size));
            // キーワード検索（URL）のブックマーク件数の取得
            $hit_count = db_get_bookmarks_count4url_keyword($keyword, $target_user_id, !$is_maintenance);
            break;
        case "tag":
        default:
            // キーワード検索（タグ）のブックマーク一覧情報の取得、設定
            $this->assign('bookmarks', db_get_bookmarks4tag_keyword($keyword, $target_user_id, !$is_maintenance, $page, $bookmark_size));
            // キーワード検索（タグ）のブックマーク件数の取得
            $hit_count = db_get_bookmarks_count4tag_keyword($keyword, $target_user_id, !$is_maintenance);
            break;
        }

        // ページング情報の設定
        $this->assignPagingInfo($page, $bookmark_size, $hit_count);

        /**
         *  基本情報の設定
         */
        // ページタイトルの設定
        $this->assign('page_title', $user['nickname'] . ' さんのブックマーク');

        // メンテナンス権限フラグの設定
        $this->assignIsMaintenance($target_user_id);

        return POCKET_ACTION_SUCCESS;
    }

    /**
     *  認証アクションフラグ
     *
     *  @access public
     *  @return boolean true,false
     */
    function isSecure()
    {
        return false;
    }
}

?>
