<?php
/**
 * Pocket Project
 * 
 * @copyright 2007 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  ブックマーク情報更新用のActionクラス
 *
 *  @author     Shogo Minami
 *  @access     public
 *  @package    PocketSBS.pc.do
 */
class bookmarkUpdateAction extends Pocket_Sbs_Action
{
    /**
     *  アクション実行
     *
     *  @access public
     *  @param  object  $controller         コントローラ
     *  @param  object  $request            リクエスト情報
     *  @return string  success,error
     */
    function execute(&$controller, &$request)
    {
        // リクエスト情報の取得
        $target_user_id = $request['target_user_id'];
        $bookmark_id    = $request['bookmark_id'];
        $url_id         = $request['url_id'];
        $subject        = $request['subject'];
        $explanation    = $request['explanation'];
        $tags           = $request['tags'];
        $open_type      = $request['open_type'];
        $referer        = $request['referer'];

        // タグの半角カナを全角カナに変換
        if (function_exists('mb_convert_kana'))
            $tags = mb_convert_kana($tags, 'KV');

        // ブックマーク情報の更新
        db_update_bookmark($bookmark_id, $target_user_id, $url_id, $subject, $explanation, $tags, $open_type);

        // リファラの存在チェック
        if ($referer && $referer != pocket_getSiteUrl())
        {
            // 指定URLへリダイレクト
            pocket_redirect4location($referer);
        }
        else {
            // ブックマーク一覧へリダイレクト
            pocket_redirect('bookmarkList.view', array('target_user_id' => $target_user_id));
        }
    }

    /**
     *  リクエスト検証
     *
     *  @access public
     *  @param  object  $validator          バリデータ
     *  @param  object  $request            リクエスト情報
     */
    function validate(&$validator, &$request)
    {
        // リクエスト情報の取得
        $target_user_id = $request['target_user_id'];
        $bookmark_id    = $request['bookmark_id'];
        $url_id         = $request['url_id'];
        $subject        = $request['subject'];
        $explanation    = $request['explanation'];
        $tags           = $request['tags'];
        $open_type      = $request['open_type'];
        $referer        = $request['referer'];

        // メンテナンス許可検証
        $this->isAllowMaintenance($target_user_id);

        // ブックマーク情報の存在チェック
        if (!db_get_bookmark($bookmark_id))
            pocket_redirect('default.view');

        // エラー表示用のAction名称の設定
        $this->viewAction = 'bookmarkEdit';

        // 検証
        $validator->validate('bookmark_id', 'ID'      , $bookmark_id, 'number', true);
        $validator->validate('subject'    , 'タイトル', $subject    , 'string', true);
        $validator->validate('explanation', '説明'    , $explanation, 'string', false);
        $validator->validate('tags'       , 'タグ'    , $tags       , 'string', false);
        $validator->validate('open_type'  , '公開状態', $open_type  , 'number', true);
    }
}

?>
