<?php
/**
 * Pocket Project
 * 
 * @copyright 2007 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  ログイン処理用のActionクラス
 *
 *  @author     Shogo Minami
 *  @access     public
 *  @package    PocketSBS.pc.do
 */
class loginAction extends Pocket_Sbs_Action
{
    /**
     *  アクション実行
     *
     *  @access public
     *  @param  object  $controller         コントローラ
     *  @param  object  $request            リクエスト情報
     *  @return string  success,error
     */
    function execute(&$controller, &$request)
    {
        // リクエスト情報の取得
        $id       = $request['id'];
        $password = $request['password'];
        $is_save  = $request['is_save'];

        // セッション情報を保持
        $temp = $_SESSION;
        // セッションの破棄
        session_destroy();
        // セッションIDの生成
        session_id(md5(uniqid(rand(), true)));
        // セッションの有効期限の設定
        ini_set('session.gc_maxlifetime', POCKET_SBS_SESSION_MAX_LIFE_TIME_PC);

        // GCプロセスの始動確率の設定
        ini_set('session.gc_probability', POCKET_SBS_SESSION_PROBABILITY);

        ini_set('session.gc_divisor', POCKET_SBS_SESSION_DIVISOR);
        // セッションの開始
        session_start();
        // セッション情報の復元
        $_SESSION = $temp;

        // ユーザIDの取得
        $user_id = db_get_user_id($id);

        // ログインユーザ情報を保持
        $_SESSION['user_id'] = $user_id;
        $_SESSION['password'] = $password;
        $_SESSION['login_module'] = 'pc';

        // Cookieに保存
        if ($is_save)
        {
            // user_id ではなく id を保存
            pocket_setCookie('user_id', $id);
        }

        // リダイレクト
        pocket_redirect('bookmarkList.view');
    }

    /**
     *  リクエスト検証
     *
     *  @access public
     *  @param  object  $validator          バリデータ
     *  @param  object  $request            リクエスト情報
     */
    function validate(&$validator, &$request)
    {
        // リクエスト情報の取得
        $id       = $request['id'];
        $password = $request['password'];

        // エラー表示用のAction名称の設定
        $this->viewAction = 'tologin';

        // 検証
        $validator->validate('id'      , 'ID'        , $id      , 'string', true);
        $validator->validate('password', 'パスワード', $password, 'alnum' , true);

        // ユーザIDの取得
        $user_id = db_get_user_id($id);

        // ID、パスワードの認証
        if (!db_auth_user4password($user_id, md5($password)))
        {
            $validator->addErrors('id', 'ユーザ認証に失敗しました。');
        }

        // 有効チェック
        if (!$validator->isValid())
        {
            // エラーメッセージをクリア
            $validator->clearErrors();
            $validator->addErrors('id', 'ログインに失敗しました。');
        }
    }

    /**
     *  認証アクションフラグ
     *
     *  @access public
     *  @return boolean true,false
     */
    function isSecure()
    {
        return false;
    }
}

?>
