<?php
/**
 * Pocket Project
 * 
 * @copyright 2007 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  ブックマーク登録画面表示用のActionクラス
 *
 *  @author     Shogo Minami
 *  @access     public
 *  @package    PocketSBS.pc.view
 */
class bookmarkEntryAction extends Pocket_Sbs_Action
{
    /**
     *  アクション実行
     *
     *  @access public
     *  @param  object  $controller         コントローラ
     *  @param  object  $request            リクエスト情報
     *  @return string  success,error
     */
    function execute(&$controller, &$request)
    {
        // リクエスト情報の取得
        $target_user_id = $request['target_user_id'];
        $bookmark_id    = $request['bookmark_id'];
        $subject        = $request['subject'];
        $url            = $request['url'];
        $keyword        = $request['keyword'];
        $explanation    = $request['explanation'];
        $tags           = $request['tags'];
        $open_type      = $request['open_type'];
        $referer        = $request['referer'];

        /**
         *  メイン情報の取得、設定
         */
        // ターゲットユーザIDの設定
        $this->assign('target_user_id', $target_user_id);

        // ユーザ情報の取得
        $user = db_get_user($target_user_id);

        // ユーザ情報の存在チェック
        if (!$user)
            pocket_redirect('default.view');

        // ユーザ情報の設定
        $this->assign('user', $user);

        // 内部のブックマークリンクからの登録かチェック
        if ($bookmark_id)
        {
            // ブックマーク情報の取得
            $bookmark = db_get_bookmark($bookmark_id);
            // リクエストのブックマーク情報を上書き
            $request['subject'] = $bookmark['subject'];
            $request['url']     = $bookmark['url'];
        }

        // ブックマークレットからの登録かチェック
        if ($request['subject'] && $request['url'] && !$request['referer'])
        {
            // ブックマークレットからの情報を設定
            $this->assign('subject', $request['subject']);
            $this->assign('url'    , $request['url']);
        }

        // 内部のブックマークリンクかブックマークレットからの登録かチェック
        if ($bookmark_id || ($request['subject'] && $request['url'] && !$request['referer']))
        {
            // リファラを設定
            $this->assign('referer', $_SERVER["HTTP_REFERER"]);
            // URLの重複チェック
            if (db_is_exist_bookmark4user_url($target_user_id, $request['url']))
            {
                // メッセージの設定
                $this->assign('message', 'URLは既に登録済みです。');
            }
        }

        // ユーザのデフォルトの公開区分の設定
        $this->assign('open_type', $user['default_open_type']);

        // 検証エラーデータの復元
        if (!$this->isValid())
        {
            $this->assign('subject'    , $request['subject']);
            $this->assign('url'        , $request['url']);
            $this->assign('keyword'    , $request['keyword']);
            $this->assign('explanation', $request['explanation']);
            $this->assign('tags'       , $request['tags']);
            $this->assign('open_type'  , $request['open_type']);
            $this->assign('referer'    , $request['referer']);
        }

        // ユーザのタグ情報の取得、設定
        $this->assign('my_tags_list', db_get_tags4user_id($target_user_id));
        // URLのタグ情報の取得、設定
        $this->assign('url_tags_list', db_get_tags4url($request['url']));

        /**
         *  基本情報の設定
         */
        // ページタイトルの設定
        $this->assign('page_title', 'ブックマークの追加');

        // 指定ユーザのタグ情報の取得、設定
        $this->assign('user_tags_list', psb_makeTagCloud(db_get_tags4user_id($target_user_id)));

        // サイドメニュー情報の設定
        $this->assignSideMenuInfo();

        return POCKET_ACTION_SUCCESS;
    }

    /**
     *  リクエスト検証
     *
     *  @access public
     *  @param  object  $validator          バリデータ
     *  @param  object  $request            リクエスト情報
     */
    function validate(&$validator, &$request)
    {
        // ブックマークレットからの要求を考慮してリクエスト情報を補正
        $request['target_user_id'] = $_SESSION['user_id'];
        if ($request['title'])
        {
            $request['subject'] = $request['title'];
        }

        // リクエスト情報の取得
        $target_user_id = $request['target_user_id'];

        // メンテナンス許可検証
        $this->isAllowMaintenance($target_user_id);
    }
}

?>
